@@ -1,3 +1,4 @@
+// Package sha1sum provides the sha1sum command.
 package sha1sum
 
 import (
@@ -34,12 +35,15 @@ to running ` + "`rclone hashsum SHA1 remote:path`" + `.
 
 This command can also hash data received on standard input (stdin),
 by not passing a remote:path, or by passing a hyphen as remote:path
-when there is data to read (if not, the hypen will be treated literaly,
+when there is data to read (if not, the hyphen will be treated literally,
 as a relative path).
 
 This command can also hash data received on STDIN, if not passing
 a remote:path.
 `,
+	Annotations: map[string]string{
+		"versionIntroduced": "v1.27",
+	},
 	RunE: func(command *cobra.Command, args []string) error {
 		cmd.CheckArgs(0, 1, command, args)
 		if found, err := hashsum.CreateFromStdinArg(hash.SHA1, args, 0); found {
